@@ -1,11 +1,16 @@
 package Firewall::Policy::Designer::Checkpoint;
 
-use Carp;
+#------------------------------------------------------------------------------
+# 加载扩展模块
+#------------------------------------------------------------------------------
 use Moose;
 use namespace::autoclean;
+
+#------------------------------------------------------------------------------
+# 加载项目模块
+#------------------------------------------------------------------------------
 use Firewall::Utils::Ip;
 use Firewall::Policy::Searcher::Report::FwInfo;
-use Mojo::Util qw(dumper);
 
 has dbi => (
   is       => 'ro',
